/**************************************************************************
 
   Module Name    = SQLENV.H
 
   Descriptive Name = External Include File for Environment Commands
 
   Copyright = nnnnnnnn (C) Copyright IBM Corp. 1989
               Licensed Material - Program Property of IBM
               Refer to Copyright Instructions Form Number G120-3083
 
   Function = Include File defining
                Database Environment Command Interfaces
                SQL Return Codes in SQLCODE for Environment Commands
 
   Operating System = PC/DOS
 
**************************************************************************/
 
/* Interface Parameters/Structures/Return Codes */
 
/* Parameters for START USING DATABASE */
 
#define   SQL_USE_SHR             'S'    /* USE = Share */
#define   SQL_USE_EXC             'X'    /* USE = Exclusive */
 
/* Sizes for parameters in sqledinfo */
 
#define   SQL_ALIAS_SZ            8
#define   SQL_USERID_SZ           8
#define   SQL_DBNAME_SZ           8
#define   SQL_NNAME_SZ            8
#define   SQL_DBTYP_SZ           20
#define   SQL_CMT_SZ             30
 
/* Parameters for Adapter */
 
#define   SQL_ADAPT_PRIM         '0'    /* Primary adapter */
#define   SQL_ADAPT_ALT          '1'    /* Alternate adapter */
 
 
struct sqledinfo
{
   unsigned char alias[SQL_ALIAS_SZ];      /* Alias name */
   unsigned char dbname[SQL_DBNAME_SZ];    /* Database name */
   unsigned char nodename[SQL_NNAME_SZ];   /* Node name associated with dbase */
   unsigned char dbtype[SQL_DBTYP_SZ];     /* Release information */
   unsigned char comment[SQL_CMT_SZ];      /* Comment   */
   short         com_codepage;             /* Code page of comment */
   char  adapter;                          /* Adapter number (0 or 1) */
};
 

 
/* Database Environment Commands -- Function Prototypes */
 
#ifndef SQL_API_FN
#define SQL_API_FN far pascal _loadds
#endif
 
#ifdef LINT_ARGS   /* argument checking enabled */
 

                                        /* MIGRATE DATABASE */
 
int SQL_API_FN sqlemigd     (unsigned char *,          /* database name */
                              unsigned char *,         /* password      */
                              struct sqlca * );        /* SQLCA pointer */
 
                                        /* INTERRUPT */
int SQL_API_FN sqleintr     (void);
 
int SQL_API_FN sqleint2     (unsigned);
 
                                        /* CATALOG DATABASE */
int SQL_API_FN sqlecatd     (unsigned char *,          /* database           */
                              unsigned char *,         /* alias              */
                              unsigned char,           /* spare1, was type   */
                              unsigned char *,         /* nodename           */
                              char,                    /* adapter, was drive */
                              unsigned char *,         /* comment          */
                              short,                   /* comment codepage */
                              struct sqlca *);         /* SQLCA            */
 
                                        /* UNCATALOG DATABASE    */
int SQL_API_FN sqleuncd     (unsigned char *,          /* database */
                              struct sqlca *);         /* SQLCA    */
 
                                        /* START DOS REQUESTOR   */
int SQL_API_FN sqlestar     ( void );
 
                                        /* STOP DOS REQUESTOR   */
int SQL_API_FN sqlestop     (struct sqlca *);         /* SQLCA    */
 
                                        /* START USING DATABASE  */
int SQL_API_FN sqlestrd     (unsigned char *,          /* database */
                              unsigned char,           /* use      */
                              struct sqlca *);         /* SQLCA    */
 
                                        /* STOP USING DATABASE   */
int SQL_API_FN sqlestpd     (struct sqlca *);          /* SQLCA */
 
 
                                        /* OPEN DIRECTORY SCAN */
int SQL_API_FN sqledops     (unsigned char,            /* spare, was drive */
                              unsigned short *,        /* handle           */
                              unsigned short *,        /* count            */
                              struct sqlca *);         /* SQLCA            */
 
                                        /* GET NEXT DIRECTORY ENTRY */
int SQL_API_FN sqledgne     (unsigned short,           /* handle */
                              struct sqledinfo **,     /* buffer */
                              struct sqlca *);         /* SQLCA  */
 
                                        /* CLOSE DIRECTORY SCAN */
int SQL_API_FN sqledcls     (unsigned short,           /* handle */
                              struct sqlca *);         /* SQLCA  */
 
                                        /* CHANGE DATABASE COMMENT */
int SQL_API_FN sqledchg     (unsigned char *,          /* database         */
                              unsigned char,           /* spare1, was drive */
                              unsigned char *,         /* comment           */
                              short,                   /* comment codepage  */
                              struct sqlca *);         /* SQLCA             */
 
                                        /* RESTART DATABASE */
int SQL_API_FN sqlerest     (unsigned char *,          /* database */
                              struct sqlca *);         /* SQLCA    */
 
                                        /* STORED PROCEDURE */
int SQL_API_FN sqleproc     (char *,                   /* program name */
                              struct sqlchar *,        /* input        */
                              struct sqlda  *,         /* input SQLDA  */
                              struct sqlda  *,         /* output SQLDA */
                              struct sqlca *);         /* SQLCA        */
 

                     /* GENERIC API FOR MIGRATE DATABASE   */
int SQL_API_FN SQLGMIGD(
                        unsigned short,          /* Database name length */
                        unsigned short,          /* Password length      */
                        unsigned char *,         /* database name        */
                        unsigned char *,         /* password             */
                        struct sqlca *           /* SQLCA pointer        */
                       );
 
                     /* GENERIC API FOR STOP USING DATABASE   */
int SQL_API_FN SQLGSTPD(
                        struct sqlca  far *      /* sqlca */
                       );
 
                     /* GENERIC API FOR START USING DATABASE  */
int SQL_API_FN SQLGSTRD(
                        unsigned short,          /* spare1          */
                        unsigned short,          /* database length */
                        unsigned char,           /* use             */
                        struct sqlca  far *,     /* sqlca           */
                        unsigned char far *,     /* spare2          */
                        unsigned char far *      /* database        */
                       );
 

                     /* GENERIC API FOR UNCATALOG DATABASE    */
int SQL_API_FN SQLGUNCD(
                        unsigned short,          /* database length */
                        struct sqlca  far *,     /* sqlca           */
                        unsigned char far *      /* database        */
                       );
 
                     /* GENERIC API FOR CATALOG DATABASE */
int SQL_API_FN SQLGCATD(
                        unsigned short,          /* comment length     */
                        unsigned short,          /* nn length          */
                        unsigned short,          /* alias length       */
                        unsigned short,          /* db length          */
                        char,                    /* adapter, was drive */
                        short,                   /* cmt code page      */
                        unsigned char,           /* spare1, was type   */
                        struct sqlca  far *,     /* sqlca              */
                        unsigned char far *,     /* comment            */
                        unsigned char far *,     /* node name          */
                        unsigned char far *,     /* alias              */
                        unsigned char far *      /* database           */
                       );
 
                     /* GENERIC API FOR INTERRUPT    */
int SQL_API_FN SQLGINTR(
                        void
                       );
 
                     /* GENERIC API FOR WINDOWS INTERRUPT    */
int SQL_API_FN SQLGINT2(
                        unsigned
                       );
 
                     /* GENERIC API FOR CHANGE DATABASE COMMENT */
int SQL_API_FN SQLGDCHG(
                        unsigned short,          /* cmt length        */
                        unsigned short,          /* db length         */
                        short,                   /* cmt codepage      */
                        unsigned char,           /* spare1, was drive */
                        struct sqlca  far *,     /* sqlca             */
                        unsigned char far *,     /* comment           */
                        unsigned char far *      /* database          */
                       );
 
                     /* GENERIC API FOR OPEN DIRECTORY SCAN */
int SQL_API_FN SQLGDOPS(
                        unsigned char,           /* spare1, was drive */
                        unsigned short far *,    /* handle            */
                        unsigned short far *,    /* count             */
                        struct sqlca   far *     /* sqlca             */
                       );
 
                     /* GENERIC API FOR GET NEXT DIRECTORY ENTRY */
int SQL_API_FN SQLGDGNE(
                        unsigned short,          /* handle */
                        struct sqledinfo far **, /* buffer */
                        struct sqlca    far *    /* sqlca  */
                       );
 
                     /* GENERIC API FOR CLOSE DIRECTORY SCAN */
int SQL_API_FN SQLGDCLS(
                        unsigned short,          /* handle */
                        struct sqlca  far *      /* sqlca  */
                       );
 
                     /* GENERIC API FOR RESTART DATABASE */
int SQL_API_FN SQLGREST(
                        unsigned short,          /* spare1          */
                        unsigned short,          /* database length */
                        struct sqlca  far *,     /* sqlca           */
                        unsigned char far *,     /* spare2          */
                        unsigned char far *      /* database        */
                       );
 
                     /* GENERIC API FOR DATABASE APPLICATION REMOTE INTERFACE */
int SQL_API_FN SQLGPROC(
                        unsigned short,          /* program name length      */
                        struct sqlca far *,      /* sqlca                    */
                        char far *,              /* Path Name of prog to run */
                        struct sqlda *,          /* Add of input sqlda       */
                        struct sqlda *,          /* Add of output sqlda      */
                        struct sqlchar *         /* Add of var length area   */
                       );
 
                     /* GENERIC API FOR START DATABASE MANAGER   */
int SQL_API_FN SQLGSTAR(
                        void
                       );
 
                     /* GENERIC API FOR STOP DATABASE MANAGER   */
int SQL_API_FN SQLGSTDM(
                        struct sqlca  far *      /* sqlca */
                       );

#else
 
int SQL_API_FN sqlemigd();
int SQL_API_FN sqleintr();
int SQL_API_FN sqleint2();
int SQL_API_FN sqlecatd();
int SQL_API_FN sqleuncd();
int SQL_API_FN sqlestrd();
int SQL_API_FN sqlestpd();
int SQL_API_FN sqledops();
int SQL_API_FN sqledgne();
int SQL_API_FN sqledcls();
int SQL_API_FN sqledchg();
int SQL_API_FN sqlerest();
int SQL_API_FN sqleproc();
int SQL_API_FN sqlestar();
int SQL_API_FN sqlestop();
int SQL_API_FN SQLGMIGD();
int SQL_API_FN SQLGSTPD();
int SQL_API_FN SQLGSTRD();
int SQL_API_FN SQLGUNCD();
int SQL_API_FN SQLGCATD();
int SQL_API_FN SQLGINTR();
int SQL_API_FN SQLGINT2();
int SQL_API_FN SQLGDCHG();
int SQL_API_FN SQLGDOPS();
int SQL_API_FN SQLGDGNE();
int SQL_API_FN SQLGDCLS();
int SQL_API_FN SQLGREST();
int SQL_API_FN SQLGPROC();
int SQL_API_FN SQLGSTAR();
int SQL_API_FN SQLGSTDM();
 
#endif  /* LINT_ARGS */
 

/* SQL Return Codes in SQLCODE for Environment Commands */
 
 
#ifndef SQL_RC_OK
 
#define SQL_RC_OK 0                     /* everything is ok */
 
#endif
 
 
 
#ifndef SQL_RC_INVALID_SQLCA
 
#define SQL_RC_INVALID_SQLCA  -1        /* invalid sqlca    */
 
#endif
 
 
#define   SQLE_RC_E953            -953  /* agent heap too small              */
#define   SQLE_RC_E957            -957  /* requestor comm heap too small     */
#define   SQLE_RC_E959            -959  /* server comm heap too small        */
#define   SQLE_RC_E961            -961  /* rqstr remote svcs heap too small  */
#define   SQLE_RC_E962            -962  /* svr remote svcs heap too small    */
 
#define   SQLE_RC_INVALIAS        -1000 /* invalid alias                     */
#define   SQLE_RC_INVDBNAME       -1001 /* invalid database name             */
#define   SQLE_RC_INVDRIVE        -1002 /* invalid drive                     */
#define   SQLE_RC_INVPSW          -1003 /* invalid password                  */
#define   SQLE_RC_INSSTOR         -1004 /* insuf storage on file system      */
#define   SQLE_RC_DUPALIAS        -1005 /* duplicate alias                   */
#define   SQLE_RC_WRONGCODEPG     -1006 /* Appl code page does not match db  */
#define   SQLE_RC_INV_NEWPSW      -1008 /* invalid new password              */
#define   SQLE_RC_INVREMOTE       -1009 /* invalid remote command            */
 
#define   SQLE_RC_INVTYPE         -1010 /* invalid type                      */
#define   SQLE_RC_NODRIVE         -1011 /* no drive for indirect entry       */
#define   SQLE_RC_NONODE          -1012 /* no nodename for remote entry      */
#define   SQLE_RC_NODB            -1013 /* alias or database name not found  */
#define   SQLE_RC_NOMORE           1014 /* no more entries                   */
#define   SQLE_RC_DB_RESTART      -1015 /* database needs restart            */
#define   SQLE_RC_INVLLU          -1016 /* invalid local_lu name             */
#define   SQLE_RC_INVMODE         -1017 /* invalid mode                      */
#define   SQLE_RC_DUPNODE         -1018 /* duplicate node name               */
#define   SQLE_RC_INVNODE         -1019 /* invalid node name                 */
 
#define   SQLE_RC_MAXNODE         -1020 /* node could not be cataloged       */
#define   SQLE_RC_NOTNODE         -1021 /* nodename not found                */
#define   SQLE_RC_INSSYS          -1022 /* insufficient system resources     */
#define   SQLE_RC_NOCONV          -1023 /* communication conversation failed */
#define   SQLE_RC_NOSUDB          -1024 /* no start using database issued    */
#define   SQLE_RC_DBACT           -1025 /* databases are active              */
#define   SQLE_RC_INVSTRT         -1026 /* DATABASE MANAGER already started  */
#define   SQLE_RC_NONODEDIR       -1027 /* node directory not found          */
#define   SQLE_RC_INVRLU          -1029 /* invalid remote lu name            */
 
#define   SQLE_RC_MAXDB           -1030 /* database directory full           */
#define   SQLE_RC_NODBDIR         -1031 /* database directory not found      */
#define   SQLE_RC_NOSTARTG        -1032 /* START DATABASE MANAGER not issued */
#define   SQLE_RC_DIRBUSY         -1033 /* database directory being updated  */
#define   SQLE_RC_DBBAD           -1034 /* database is damaged               */
#define   SQLE_RC_DB_INUSE        -1035 /* database already in use           */
#define   SQLE_RC_FILEDB          -1036 /* database file error               */
#define   SQLE_RC_FILENODE        -1038 /* node directory file error         */
#define   SQLE_RC_FILEDIR         -1039 /* directory file error              */
 
#define   SQLE_RC_MAXAPPLS        -1040 /* Maximum Number of applications    */
#define   SQLE_RC_MAXDBS          -1041 /* Maximum Number of DB started      */
#define   SQLE_RC_SYSERR          -1042 /* system error                      */
#define   SQLE_RC_CATBOOT         -1043 /* catalog bootstrap failure         */
#define   SQLE_RC_INTRRPT         -1044 /* request interrupted by ctrl+break */
#define   SQLE_RC_INVINDIR        -1045 /* invalid level of indirection      */
#define   SQLE_RC_INVAUTHID       -1046 /* invalid userid                    */
#define   SQLE_RC_APCONN          -1047 /* appl already connect to another db*/
#define   SQLE_RC_USEINVALID      -1048 /* invalid use specified             */
#define   SQLE_RC_APPSERR         -1049 /* appl state in error               */
 
#define   SQLE_RC_UNCHOME         -1050 /* cannot uncatalog home database    */
#define   SQLE_RC_NODIRDRV        -1051 /* db direct. drive does not exist   */
#define   SQLE_RC_NODBDRV         -1052 /* database drive does not exist     */
#define   SQLE_RC_INTBUSY         -1053 /* interrupt already in progress     */
#define   SQLE_RC_COMMINP         -1054 /* commit in progress - no int's     */
#define   SQLE_RC_ROLLINP         -1055 /* rollback in progress - no int's   */
#define   SQLE_RC_MAXSCAN         -1056 /* maximun allowable scans exceeded  */
#define   SQLE_RC_NODENTRY         1057 /* no entries in directory           */
#define   SQLE_RC_INVHAND         -1058 /* invalid input handle              */
#define   SQLE_RC_NOSCAN          -1059 /* open scan not issued              */
 
#define   SQLE_RC_NOCONNECT       -1060 /* user lacks connect privilege      */
#define   SQLE_RC_BADPATH         -1062 /* database path not found           */
#define   SQLE_RC_START_OK        -1063 /* startdbs successful               */
#define   SQLE_RC_STOP_OK         -1064 /* stopdbs successful                */
#define   SQLE_RC_DB_BADBINDS      1065 /* n utilities not bound             */
#define   SQLE_RC_NOMSG           -1068 /* message file not found            */
#define   SQLE_RC_INVDROP         -1069 /* DB invalid type for drop          */
 
#define   SQLE_RC_INVDBNAME_PTR   -1070 /* Invalid Database Name ptr         */
#define   SQLE_RC_INVALIAS_PTR    -1071 /* Invalid Alias pointer             */
#define   SQLE_RC_INVPSW_PTR      -1074 /* Invalid Password pointer          */
#define   SQLE_RC_INVCOMM_PTR     -1075 /* Invalid Comment pointer           */
#define   SQLE_RC_INVCNT_PTR      -1076 /* Invalid Count pointer             */
#define   SQLE_RC_INVHAND_PTR     -1077 /* Invalid Handle Pointer            */
#define   SQLE_RC_INVBUFF_PTR     -1078 /* Invalid Buffer pointer            */
#define   SQLE_RC_INVNODE_PTR     -1079 /* Invalid Node Pointer              */
 
#define   SQLE_RC_INVLLU_PTR      -1080 /* Invalid Local Lu Pointer          */
#define   SQLE_RC_INVRLU_PTR      -1081 /* Invalid Remote Lu Pointer         */
#define   SQLE_RC_INVMODE_PTR     -1082 /* Invalid Mode Pointer              */
#define   SQLE_RC_KSEGSFAIL       -1084 /* Cannot Allocate Kernel Segments   */
#define   SQLE_RC_APPHEAPFAIL     -1085 /* Cannot Allocate Application heap  */
#define   SQLE_RC_OS2ERROR        -1086 /* Unexpected OS/2 error             */
#define   SQLE_RC_BIND_LIST        1087 /* Bind list could not be opened     */
#define   SQLE_RC_BIND_ERROR       1088 /* Error occurred during bind        */
#define   SQLE_RC_BIND_INTRRPT     1089 /* Binding was interrupted           */
 
#define   SQLE_RC_BAD_APP_REL     -1090 /* Release number of APP is invalid  */
#define   SQLE_RC_BAD_DB_REL      -1091 /* Release number of database bad    */
 
#define   SQLE_RC_INSAUTH         -1092 /* Authorization error               */
#define   SQLE_RC_NOLOGON         -1093 /* User not logged on                */
#define   SQLE_RC_NDBUSY          -1094 /* Node dir being updated            */
#define   SQLE_RC_MAX_NDSCAN      -1095 /* Max node scans open               */
#define   SQLE_RC_REQTYPE         -1096 /* Invalid type for requester node   */
#define   SQLE_RC_NODERR          -1097 /* Node not found for remote db      */
#define   SQLE_RC_APCONN_SAME     -1098 /* appl is already connected to db   */
#define   SQLE_RC_WRPROT_ERR      -1099 /* write protect error on diskette   */
 
#define   SQLE_RC_NODE_WARN        1100 /* node not cataloged for database   */
#define   SQLE_RC_REMCONN_ERR     -1101 /* remote communications error       */
#define   SQLE_RC_MIG_NODB        -1102 /* No Database Name provided in Call */
#define   SQLE_RC_MIG_OK          -1103 /* Migration Successful Message      */
#define   SQLE_RC_INVPROG_PTR     -1104 /* Invalid program name pointer     */
#define   SQLE_RC_INV_SPDB        -1105 /* Invalid Stop Using Database       */
#define   SQLE_RC_INVALID_PROC    -1106 /* Program invalid                   */
#define   SQLE_RC_INTRP_PROC      -1107 /* Program interrupted               */
#define   SQLE_RC_SYSERR_PROC     -1108 /* Unexpected I/O or OS/2 error      */
#define   SQLE_RC_NOFILE_PROC     -1109 /* Program file not found            */
#define   SQLE_RC_ERROR_PROC      -1110 /* Program error                     */
#define   SQLE_RC_BADPGN_PROC     -1111 /* Invaild DLL name format           */
#define   SQLE_RC_INSMEM_PROC     -1112 /* No memory loading DLL             */
#define   SQLE_RC_SQLDA_DATATYPE  -1113 /* Data type in output SQLDA changed */
#define   SQLE_RC_SQLDA_LENGTH    -1114 /* Data length in output SQLDA change*/
#define   SQLE_RC_SQLDA_VARS      -1115 /* Number of sqlvars changed in SQLDA*/
#define   SQLE_RC_INVADAPTER      -1125 /* invalid adapter number            */
 
#define   SQLE_RC_INVOS_OBJ       -1200 /* invalid object specified          */
#define   SQLE_RC_INVOS_STAT      -1201 /* invalid status specified          */
#define   SQLE_RC_INVOS_NOSTAT    -1202 /* status has not been collected     */
#define   SQLE_RC_INVOS_NOUSER    -1203 /* no users connected to database    */
#define   SQLE_RC_UNSUPP_CODEPG   -1204 /* active codepage in not supported  */
#define   SQLE_RC_WIN_NOTASK      -1215 /* target task of interrupt not found*/
#define   SQLE_RC_DRDANSP         -1325 /* Remote function not supported     */
 
#define   SQLE_RC_PRTCLERR       -30020 /* Distribution protocol error       */
#define   SQLE_RC_CMPERR         -30021 /* Distribution compatibility error  */
#define   SQLE_RC_MEMORY         -30040 /* Distribution memory allocation err*/
#define   SQLE_RC_CMDNSP         -30070 /* Distribution command error        */
#define   SQLE_RC_OBJNSP         -30071 /* Distribution object error         */
#define   SQLE_RC_PRMNSP         -30072 /* Distribution parameter error      */
#define   SQLE_RC_VALNSP         -30073 /* Distribution parameter value error*/
#define   SQLE_RC_RPYNSP         -30074 /* Distribution reply error          */
